@@ -1,9 +1,9 @@
 # encoding: utf-8
 
 require File.expand_path(File.join(File.dirname(__FILE__), 'spec_helper'))
-require 'data_objects/spec/command_spec'
+require 'data_objects/spec/shared/command_spec'
 
 describe DataObjects::Postgres::Command do
-  behaves_like 'a Command'
-  behaves_like 'a Command with async'
+  it_should_behave_like 'a Command'
+  it_should_behave_like 'a Command with async'
 end
